# Kuzu WebAssembly Node.js Example
This example demonstrates how to use the Kuzu WebAssembly build in a Node.js environment. The example uses the asynchronous JavaScript API to interact with the WebAssembly module.

## Usage
### Install Dependencies
```bash
npm i
```

### Run the example
```bash
npm start
```

## Source Code
The source code for this example can be found in the `index.js` file. 
